<template>
  <a-modal :title='title' :width='500' :visible='visible' :maskClosable='false' :confirmLoading='confirmLoading'
           :okButtonProps='{ props: {disabled: disableSubmit} }' @ok='handleOk' @cancel='handleCancel' cancelText='关闭'>
    <a-spin :spinning='confirmLoading'>
      <a-form :form='form'>
        <a-row :gutter='32'>
          <a-col :span='32'>
            <a-form-item :labelCol='labelCol' :wrapperCol='wrapperCol' label='授权信息'>
              <a-textarea :disabled='disableSubmit' :readOnly='disableSubmit' placeholder='请输入授权信息' allow-clear
                          v-decorator="['authorize']" />
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </a-spin>
    <template slot='footer'>
      <a-button :style="{ marginRight: '8px' }" @click='handleCancel'>关闭</a-button>
      <a-button @click='handleOk' type='primary'>确定</a-button>
    </template>
  </a-modal>
</template>

<script>
import pick from 'lodash.pick'
import { httpAction } from '@/api/manage'

export default {
  name: 'AuthorizeModel',

  data() {
    return {
      title: '',
      visible: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      url: {
        edit: '/serve/deploy/edit'
      },
      disableSubmit: false
    }
  },

  methods: {
    add() {
      this.edit({})
    },
    edit(record) {
      this.form.resetFields()
      this.model = Object.assign({}, record)
      this.visible = true
      this.$nextTick(() => {
        this.form.setFieldsValue(pick(this.model, 'authorize'))
      })
    },
    close() {
      this.$emit('close')
      this.visible = false
    },
    handleOk() {
      const that = this
      // 触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true
          let formData = Object.assign(this.model, values)
          httpAction(this.url.edit, formData, 'put')
            .then((res) => {
            if (res.success) {
              that.$message.success("更新授权成功！")
              that.$emit('ok', res.result)
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
            that.close()
          })
        }
      })
    },
    handleCancel() {
      this.close()
    },
  }
}
</script>

<style scoped>

</style>
